===============================
cellpy
===============================


.. image:: https://img.shields.io/pypi/v/cellpy.svg
        :target: https://pypi.python.org/pypi/cellpy

.. image:: https://img.shields.io/travis/jepegit/cellpy.svg
        :target: https://travis-ci.org/jepegit/cellpy

.. image:: https://readthedocs.org/projects/cellpy/badge/?version=latest
        :target: https://cellpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/jepegit/cellpy/shield.svg
     :target: https://pyup.io/repos/github/jepegit/cellpy/
     :alt: Updates


This Python Package was developed to help the
researchers at IFE, Norway, in their cumbersome task of
interpreting and handling data from cycling tests of
batteries and cells.




* Free software: MIT license
* Documentation: https://cellpy.readthedocs.io.


Features
--------

* Load test-data and store in hdf5 format.
* Filter out the steps of interest.
* Process and plot the data.
* And more...

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

